@@ -17,6 +17,7 @@ from krules_core import RuleConst
 from krules_core.base_functions import RuleFunctionBase, inspect
 from krules_core.core import RuleFactory
 from krules_core.providers import event_router_factory, subject_factory, proc_events_rx_factory
+from rx import subject
 
 filters = RuleConst.FILTERS
 processing = RuleConst.PROCESSING
@@ -27,7 +28,7 @@ passed = RuleConst.PASSED
 def router():
     router = event_router_factory()
     router.unregister_all()
-    proc_events_rx_factory.queue.clear()
+    proc_events_rx_factory.override(providers.Singleton(rx_subject.ReplaySubject))
 
     return event_router_factory()
 
@@ -60,7 +61,7 @@ def test_simple_callable():
     payload = {}
     event_router_factory().route("test-argprocessors-callables", "test-0", payload)
 
-    proc_events_rx_factory.subscribe(
+    proc_events_rx_factory().subscribe(
         lambda x: x[rulename] == "test-simple-callable" and _assert(
             x[processing][0]["args"][0] == 1
             and x[processing][0]["kwargs"]["arg3"] == 3
@@ -104,7 +105,7 @@ def test_with_self():
     subject.set("value_from", 2)
 
     event_router_factory().route("test-argprocessors-self", subject, payload)
-    proc_events_rx_factory.subscribe(
+    proc_events_rx_factory().subscribe(
         lambda x: x[rulename] == "test-with-self" and _assert(
             x[processing][0]["args"][0] == 1
             and x[processing][0]["kwargs"]["arg2"] == 2
@@ -145,7 +146,7 @@ def test_with_payload_and_subject():
 
     event_router_factory().route("test-argprocessors-payload-and-subject", _subject, _payload)
 
-    proc_events_rx_factory.subscribe(
+    proc_events_rx_factory().subscribe(
         lambda x: x[rulename] == "test-with-payload-and-subject" and _assert(
             x[processing][0]["args"][0] == 1 and x[processing][0]["kwargs"]["arg2"] == 2
             and isinstance(x[processing][0]["kwargs"]["arg3"], str))
@@ -223,7 +224,7 @@ def test_extend_jp_match():
 
     event_router_factory().route("test-argprocessors-jp-match", "test-0", payload)
 
-    proc_events_rx_factory.subscribe(
+    proc_events_rx_factory().subscribe(
         lambda x: x[rulename] == "test-with-jp-expr" and _assert(
             x[processing][0]["args"][0] == ['a', 'b']
             and x[processing][0]["args"][1] == {"id": 2, "value": "b"})
